@@ -5,10 +5,10 @@ use Test::More tests => 1;
 use lib 'lib';
 
 # TEST:source "$^CURRENT_DIRNAME/lib/MyMoreTests.pm"
-use MyMoreTests;
+use MyMoreTests qw/ my_more_tests /;
 
 # TEST
-is (5, 5, "Hello");
+is( 5, 5, "Hello" );
 
 # TEST*$my_more_tests_number;
 my_more_tests();
